//  © Copyright 2010 Reuben D'Netto (rdnetto+uremote@gmail.com)
//  This file is part of uRemote v1.0
//
//  uRemote is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  uRemote is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with uRemote.  If not, see <http://www.gnu.org/licenses/>.


#ifndef ADDTORRENTDIALOG_H
#define ADDTORRENTDIALOG_H

#include <QtGui/QMainWindow>
#include "btconnection.h"

namespace Ui {
	class AddTorrentDialog;
}

class AddTorrentDialog : public QMainWindow { //QMainWindow {
	Q_OBJECT
public:
	AddTorrentDialog(QWidget *parent, BtConnection* con);
	~AddTorrentDialog();

protected:
	void changeEvent(QEvent *e);

private:
	Ui::AddTorrentDialog *m_ui;
	BtConnection *Connection;

private slots:
	void UpdateView();
	void Browse();
	void AddTorrent();
};

#endif // ADDTORRENTDIALOG_H
